==> taboola_sdk-0.2.0.tar.gz: example/lib/screens/publishers/nikib_test.dart <==
import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';


class PublisherProperties {
  final String publisher = 'nikib-app';
  final String mode = 'alternating-thumbnails-a';
  final String pageUrl = 'https://nikib.co.il/tosafot/vegetarian/78320/';
  final String pageType = 'article';
  final String placement = 'Below Article Thumbnails';
}

class NikiB extends StatelessWidget {
  ScaffoldMessengerState _scaffoldMessenger; //A reference to ScaffoldMessenger to allow sending Snackbar messages

  @override
  Widget build(BuildContext context) {
    PublisherProperties _publisherProperties = new PublisherProperties();

    Taboola.init(PublisherInfo(_publisherProperties.publisher));
    TaboolaStandardBuilder taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(_publisherProperties.pageUrl, _publisherProperties.pageType);
    TaboolaStandardListener taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    TaboolaStandard taboolaStandard = taboolaStandardBuilder.build(_publisherProperties.placement, _publisherProperties.mode, true, taboolaStandardListener);

//    TaboolaStandardListener taboolaStandardListener = TaboolaStandardListener((String placement, double height) {
//      print('didResize: $placement');
//    }
//    });


    //Define ScaffoldMessanger
    _scaffoldMessenger = ScaffoldMessenger.of(context);

    /// At the moment, SingleChildScrollView fits more our Widgets. In general, and any Feed integration, we recommend using CustomScrollView for NestedScrolling solution.
    return SingleChildScrollView(
        controller: taboolaStandard.scrollController,
        //Using SingleChildScrollView requires using 'controller: taboolaStandard.scrollController', otherwise the y value of Taboola's Unit rect does not get updated properly by Flutter.
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisSize: MainAxisSize.max,
            children: [
              Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Column(mainAxisSize: MainAxisSize.max, children: [
                    AutoSizeText(
                      "NikiB Integration",
                      maxLines: 3,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(fontSize: 30.0),
                    ),
                    const SizedBox(
                      height: 20.0,
                    ),
                    const SizedBox(
                      height: 10.0,
                    ),
                    taboolaStandard,
                  ]))
            ]));
  }


  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    if (organic) {
      _showToast("Publisher opted to open click but didn't actually open it.");
    } else {
      _showToast("Publisher opted to open clicks but the item is Sponsored, SDK retains control.");
    }
    return false;
  }

  void _showToast(String text) {
    _scaffoldMessenger.showSnackBar(
      SnackBar(
        content: Text(text),
        action: SnackBarAction(label: 'OK', onPressed: _scaffoldMessenger.hideCurrentSnackBar),
      ),
    );
  }
}

==> taboola_sdk-0.2.1.tar.gz: example/lib/screens/publishers/nikib_test.dart <==
import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/classic/taboola_classic.dart';
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

class PublisherProperties {
  final String publisher = 'nikib-app';
  final String mode = 'thumbs-feed-01';
//  final String mode = 'alternating-thumbnails-a';
  final String pageUrl = 'https://nikib.co.il/tosafot/vegetarian/78320/';
  final String pageType = 'article';
  final String placement = 'Below Article Thumbnails';
}

class NikiB extends StatelessWidget {
  ScaffoldMessengerState
      _scaffoldMessenger; //A reference to ScaffoldMessenger to allow sending Snackbar messages

  @override
  Widget build(BuildContext context) {
    PublisherProperties _publisherProperties = new PublisherProperties();

    Taboola.init(PublisherInfo(_publisherProperties.publisher));
    TaboolaClassicBuilder taboolaStandardBuilder =
        Taboola.getTaboolaClassicBuilder(
            _publisherProperties.pageUrl, _publisherProperties.pageType);
    TaboolaClassicListener taboolaStandardListener = TaboolaClassicListener(
        taboolaDidResize,
        taboolaDidShow,
        taboolaDidFailToLoad,
        taboolaDidClickOnItem);
    TaboolaClassicUnit taboolaStandard = taboolaStandardBuilder.build(
        _publisherProperties.placement,
        _publisherProperties.mode,
        true,
        taboolaStandardListener);

//    TaboolaStandardListener taboolaStandardListener = TaboolaStandardListener((String placement, double height) {
//      print('didResize: $placement');
//    }
//    });

    //Define ScaffoldMessanger
    _scaffoldMessenger = ScaffoldMessenger.of(context);

    /// At the moment, SingleChildScrollView fits more our Widgets. In general, and any Feed integration, we recommend using CustomScrollView for NestedScrolling solution.
    return SingleChildScrollView(
        controller: taboolaStandard.scrollController,
        //Using SingleChildScrollView requires using 'controller: taboolaStandard.scrollController', otherwise the y value of Taboola's Unit rect does not get updated properly by Flutter.
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisSize: MainAxisSize.max,
            children: [
              Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Column(mainAxisSize: MainAxisSize.max, children: [
                    AutoSizeText(
                      "NikiB Integration",
                      maxLines: 3,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(fontSize: 30.0),
                    ),
                    const SizedBox(
                      height: 20.0,
                    ),
                    const SizedBox(
                      height: 10.0,
                    ),
                    taboolaStandard,
                  ]))
            ]));
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(
      String placement, String itemId, String clickUrl, bool organic) {
    print(
        "publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    if (organic) {
      _showToast("Publisher opted to open click but didn't actually open it.");
    } else {
      _showToast(
          "Publisher opted to open clicks but the item is Sponsored, SDK retains control.");
    }
    return false;
  }

  void _showToast(String text) {
    _scaffoldMessenger.showSnackBar(
      SnackBar(
        content: Text(text),
        action: SnackBarAction(
            label: 'OK', onPressed: _scaffoldMessenger.hideCurrentSnackBar),
      ),
    );
  }
}
